# SignUpResponseStatus

Status of the order. `Pending` is only applicable for an order that contains a `CreateSubscription` order action.

## Enum

* `COMPLETED` (value: `'Completed'`)

* `PENDING` (value: `'Pending'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


